@@ -18,7 +18,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 
 """
 
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import absolute_import, division, print_function
 
 import os
 import shutil
@@ -34,7 +34,7 @@ from pies.overrides import *
 
 from .utils import Node
 
-FROSTED_BINARY = os.path.join(os.path.dirname(frosted.__file__), '..', 'scripts', 'frosted')
+FROSTED_BINARY = os.path.join(os.path.dirname(frosted.__file__), 'main.py')
 
 
 def setup_function(function):
@@ -145,6 +145,16 @@ def test_fileWithFlakes():
     assert d[0].strip() == expected.message.strip()
 
 
+@pytest.mark.skipif("sys.version_info >= (3,)")
+def test_non_unicode_slash_u():
+    """ Ensure \ u doesn't cause a unicode decode error """
+    fd = open(TEMP_FILE_PATH, 'wb')
+    fd.write('"""Example: C:\\foobar\\unit-tests\\test.py"""'.encode('ascii'))
+    fd.close()
+    d = run_frosted([TEMP_FILE_PATH])
+    assert d == ('', '', 0)
+
+
 def test_errors():
     """ When frosted finds errors with the files it's given, (if they don't exist, say),
 
@@ -164,7 +174,7 @@ def test_readFromStdin():
     assert d[0].strip() == expected.message.strip()
 
 
-@pytest.mark.skipif("version_info >= (3,)")
+@pytest.mark.skipif("sys.version_info >= (3,)")
 def test_print_statement_python2():
     d = run_frosted(['-'], stdin='print "Hello, Frosted"'.encode('ascii'))
     assert d == ('', '', 0)
